@@ -65,17 +65,23 @@ G_BEGIN_DECLS
 
 typedef struct _CandidatePair CandidatePair;
 typedef struct _CandidatePairKeepalive CandidatePairKeepalive;
+typedef struct _CandidatePairConsentCheck CandidatePairConsentCheck;
 typedef struct _IncomingCheck IncomingCheck;
 
 struct _CandidatePairKeepalive
 {
   guint64 next_tick;    /* next tick timestamp */
-  GSource *tick_source;
   guint stream_id;
   guint component_id;
   StunTimer timer;
-  uint8_t stun_buffer[STUN_MAX_MESSAGE_SIZE_IPV6];
-  StunMessage stun_message;
+};
+
+struct _CandidatePairConsentCheck
+{
+  GSource *tick_source;
+  gboolean have;
+  guint64 last_received;        /* g_get_monotonic_time() of last remote
+                                   consent received */
 };
 
 struct _CandidatePair
@@ -85,6 +91,7 @@ struct _CandidatePair
   guint64 priority;           /* candidate pair priority */
   guint32 stun_priority;
   CandidatePairKeepalive keepalive;
+  CandidatePairConsentCheck remote_consent;
 };
 
 struct _IncomingCheck
@@ -224,6 +231,26 @@ struct _NiceComponent {
    * ACKs on. The messages are dequeued to the pseudo-TCP socket once a selected
    * UDP socket is available. This is only used for reliable Components. */
   GQueue queued_tcp_packets;
+
+  gboolean have_local_consent;
+
+  /* scratch buffer for use in the component_io_cb() function to
+   * hold the incoming packet, allocated at component creation, since
+   * the callback is a critical path, where memory allocation should
+   * be avoided.
+   */
+  guint8 *recv_buffer;
+  guint recv_buffer_size;
+
+  /* ICE-TCP frame state */
+  guint8 *rfc4571_buffer;
+  guint rfc4571_buffer_offset;
+  guint rfc4571_buffer_size;
+  guint rfc4571_frame_offset;
+  guint rfc4571_frame_size;
+  guint rfc4571_consumed_size;
+  NiceAddress rfc4571_remote_addr;
+  gboolean rfc4571_wakeup_needed;
 };
 
 typedef struct {
@@ -236,14 +263,19 @@ NiceComponent *
 nice_component_new (guint component_id, NiceAgent *agent, NiceStream *stream);
 
 void
-nice_component_close (NiceAgent *agent, NiceComponent *component);
+nice_component_close (NiceAgent *agent, NiceStream *stream,
+    NiceComponent *component);
+
+void
+nice_component_shutdown (NiceComponent *component, gboolean shutdown_read,
+    gboolean shutdown_write);
 
 gboolean
 nice_component_find_pair (NiceComponent *component, NiceAgent *agent,
     const gchar *lfoundation, const gchar *rfoundation, CandidatePair *pair);
 
 void
-nice_component_restart (NiceComponent *component);
+nice_component_restart (NiceComponent *component, NiceAgent *agent);
 
 void
 nice_component_update_selected_pair (NiceAgent *agent, NiceComponent *component,
@@ -285,7 +317,7 @@ nice_component_set_io_callback (NiceComponent *component,
     GError **error);
 void
 nice_component_emit_io_callback (NiceAgent *agent, NiceComponent *component,
-    const guint8 *buf, gsize buf_len);
+    gsize buf_len);
 gboolean
 nice_component_has_io_callback (NiceComponent *component);
 void
@@ -313,6 +345,9 @@ nice_component_verify_remote_candidate (NiceComponent *component,
 GPtrArray *
 nice_component_get_sockets (NiceComponent *component);
 
+guint
+nice_component_compute_rfc4571_headroom (NiceComponent *component);
+
 G_END_DECLS
 
 #endif /* _NICE_COMPONENT_H */
